#include <OneWire.h>
#include <DallasTemperature.h>
#include <Wire.h>

// Data wire is plugged into port 2 on the Arduino
#define ONE_WIRE_BUS 2

// Setup a oneWire instance to communicate with any OneWire devices (not just Maxim/Dallas temperature ICs)
OneWire oneWire(ONE_WIRE_BUS);

// Pass our oneWire reference to Dallas Temperature. 
DallasTemperature sensors(&oneWire);

const uint8_t     i2cAddress  = 0x50;
volatile uint8_t  numRegistre = 0;
const uint8_t     nbRegister  = 6;

volatile uint16_t valRegister[nbRegister];

void setup() {
  // Start the I2C Bus as Slave on address 
  Wire.begin(i2cAddress);
  Wire.onRequest(requestEvent);
  Wire.onReceive(receiveEvent);
  sensors.begin();
}

void receiveEvent(int nbBytes)
{
  numRegistre=Wire.read();
  while(Wire.available())    // slave may send less than requested
  {
    Wire.read();    // receive a byte as character
  }
}

void requestEvent()
{
  Wire.write(valRegister[numRegistre]);
  if (numRegistre<nbRegister) numRegistre++; else numRegistre=0;
}

void loop() {
  static int16_t temperatureMini = 1250;
  static int16_t temperatureMaxi = -550;

  sensors.requestTemperatures(); // Send the command to get temperatures
  float temp = sensors.getTempCByIndex(0);
  uint16_t value = temp*10;
  noInterrupts();
  valRegister[0] = value>>8;
  valRegister[1] = value;
  interrupts();
  if(temperatureMini>temp){ 
    temperatureMini=temp;   
    value = temp*10;
    noInterrupts();
    valRegister[2] = value>>8;
    valRegister[3] = value;
    interrupts();
  } 
  if(temperatureMaxi<temp){ 
    temperatureMaxi=temp;    
    value = temp*10;
    noInterrupts();
    valRegister[4] = value>>8;
    valRegister[5] = value;
    interrupts();
  } 
  _delay_ms(100);
}